
// Persistence of Vision Ray Tracer Scene Description File
// File: ProgTut1.inc
// Vers: POV 3.01
// Desc: First part of a tutorial on POV Scripting (How to build inc files)
// Date: 06/11/97
// Auth: Terenziani Gianluca

// Parameters for this include
// Parameter           Type            Default         Means
// POLY_RADIUS1        float > 0       1               Radius of first poly
// POLY_RADIUS2        float > 0       2               Radius of 2nd poly
// POLY_VERTEX1        integer > 2     4               Number of vertex of first poly
// POLY_VERTEX2        integer > 2     4               Number of vertex of 2nd poly

// Checking Parameters, using #ifndef statement to see if parameter exist
// if not exist using #declare to instantiate it to default value
#ifndef (POLY_RADIUS1)
    #declare POLY_RADIUS1 = 1
#end

#ifndef (POLY_RADIUS2)
    #declare POLY_RADIUS2 = 2
#end

#ifndef (POLY_VERTEX1)
    #declare POLY_VERTEX1 = 4
#end

#ifndef (POLY_VERTEX2)
    #declare POLY_VERTEX2 = 4
#end

// Now We Have all the parameters, Go to build The Poly

// First, declare the POLY object
#declare POLY =
polygon
{
    // Total Number of vertex
    POLY_VERTEX1 + POLY_VERTEX2 + 3,
    // +3, because the first and the last vertex are the same for first radius poly,
    // 2nd radius poly and for all the poly

// Loop to declare the First radius vertex
    // The subdivision of the circle (in radiant) (using built in const pi (pigreco))
    #declare POLY_CIRCLE_STEP = (pi * 2) / POLY_VERTEX1
    // Dummy var, use as counter
    #declare POLY_DUMMY = 1
    // Saving first point (for use as end point)
    #declare POLY_FIRSTP = <0,0,POLY_RADIUS1>
    // Adding First point to poly
    <POLY_FIRSTP.x,POLY_FIRSTP.y,POLY_FIRSTP.z>
    #while  (POLY_DUMMY <= POLY_VERTEX1)
        // Computing current angle
        #declare POLY_CURR_ANGLE = POLY_CIRCLE_STEP * POLY_DUMMY
        // Declaring point (compute x and z position using sin and cos functions)
        <sin(POLY_CURR_ANGLE) * POLY_RADIUS1,0,cos(POLY_CURR_ANGLE) * POLY_RADIUS1>
        // Increase counter
        #declare POLY_DUMMY = POLY_DUMMY + 1
    #end

// Loop to declare the 2nd radius vertex
    // The subdivision of the circle (in radiant) (using built in const pi (pigreco))
    #declare POLY_CIRCLE_STEP = (pi * 2) / POLY_VERTEX2
    // Dummy var, use as counter
    #declare POLY_DUMMY = 0
    #while  (POLY_DUMMY <= POLY_VERTEX2)
        // Computing current angle
        #declare POLY_CURR_ANGLE = POLY_CIRCLE_STEP * POLY_DUMMY
        // Declaring point (compute x and z position using sin and cos functions)
        <sin(POLY_CURR_ANGLE) * POLY_RADIUS2,0,cos(POLY_CURR_ANGLE) * POLY_RADIUS2>
        // Increase counter
        #declare POLY_DUMMY = POLY_DUMMY + 1
    #end

    // Adding end point (equal to firstpoint)
    <POLY_FIRSTP.x,POLY_FIRSTP.y,POLY_FIRSTP.z>
// End of polygon
}

// End

